==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/automanage/kotlin/inputs/ConfigurationProfilePreferenceAntiMalwareArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automanage.kotlin.inputs

import com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs.builder
import com.pulumi.azurenative.automanage.kotlin.enums.EnableRealTimeProtection
import com.pulumi.azurenative.automanage.kotlin.enums.RunScheduledScan
import com.pulumi.azurenative.automanage.kotlin.enums.ScanType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Automanage configuration profile Antimalware preferences.
 * @property enableRealTimeProtection Enables or disables Real Time Protection
 * @property exclusions Extensions, Paths and Processes that must be excluded from scan
 * @property runScheduledScan Enables or disables a periodic scan for antimalware
 * @property scanDay Schedule scan settings day
 * @property scanTimeInMinutes Schedule scan settings time
 * @property scanType Type of scheduled scan
 */
public data class ConfigurationProfilePreferenceAntiMalwareArgs(
    public val enableRealTimeProtection: Output<Either<String, EnableRealTimeProtection>>? = null,
    public val exclusions: Output<Any>? = null,
    public val runScheduledScan: Output<Either<String, RunScheduledScan>>? = null,
    public val scanDay: Output<String>? = null,
    public val scanTimeInMinutes: Output<String>? = null,
    public val scanType: Output<Either<String, ScanType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs> {
    override fun toJava():
        com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs =
        com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs.builder()
            .enableRealTimeProtection(
                enableRealTimeProtection?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .exclusions(exclusions?.applyValue({ args0 -> args0 }))
            .runScheduledScan(
                runScheduledScan?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .scanDay(scanDay?.applyValue({ args0 -> args0 }))
            .scanTimeInMinutes(scanTimeInMinutes?.applyValue({ args0 -> args0 }))
            .scanType(
                scanType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationProfilePreferenceAntiMalwareArgs].
 */
@PulumiTagMarker
public class ConfigurationProfilePreferenceAntiMalwareArgsBuilder internal constructor() {
    private var enableRealTimeProtection: Output<Either<String, EnableRealTimeProtection>>? = null

    private var exclusions: Output<Any>? = null

    private var runScheduledScan: Output<Either<String, RunScheduledScan>>? = null

    private var scanDay: Output<String>? = null

    private var scanTimeInMinutes: Output<String>? = null

    private var scanType: Output<Either<String, ScanType>>? = null

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("hriqugcohybgoqed")
    public suspend
    fun enableRealTimeProtection(`value`: Output<Either<String, EnableRealTimeProtection>>) {
        this.enableRealTimeProtection = value
    }

    /**
     * @param value Extensions, Paths and Processes that must be excluded from scan
     */
    @JvmName("liswxmdmljigceas")
    public suspend fun exclusions(`value`: Output<Any>) {
        this.exclusions = value
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("tgbfgvgfldynypss")
    public suspend fun runScheduledScan(`value`: Output<Either<String, RunScheduledScan>>) {
        this.runScheduledScan = value
    }

    /**
     * @param value Schedule scan settings day
     */
    @JvmName("xoideuaxmcwemalk")
    public suspend fun scanDay(`value`: Output<String>) {
        this.scanDay = value
    }

    /**
     * @param value Schedule scan settings time
     */
    @JvmName("mcmxuklnjhhlakqq")
    public suspend fun scanTimeInMinutes(`value`: Output<String>) {
        this.scanTimeInMinutes = value
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("hehscgtqxcyeplon")
    public suspend fun scanType(`value`: Output<Either<String, ScanType>>) {
        this.scanType = value
    }

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("vnyudtksxwicunqp")
    public suspend fun enableRealTimeProtection(`value`: Either<String, EnableRealTimeProtection>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableRealTimeProtection = mapped
    }

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("ajcrohqkdheafdqx")
    public fun enableRealTimeProtection(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnableRealTimeProtection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enableRealTimeProtection = mapped
    }

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("hoayvkqgbctsxfyu")
    public fun enableRealTimeProtection(`value`: EnableRealTimeProtection) {
        val toBeMapped = Either.ofRight<String, EnableRealTimeProtection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enableRealTimeProtection = mapped
    }

    /**
     * @param value Extensions, Paths and Processes that must be excluded from scan
     */
    @JvmName("hthrpxhbfjuvybjg")
    public suspend fun exclusions(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("bibdwnebvdkxouvt")
    public suspend fun runScheduledScan(`value`: Either<String, RunScheduledScan>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runScheduledScan = mapped
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("anmecykbtvejiref")
    public fun runScheduledScan(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RunScheduledScan>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.runScheduledScan = mapped
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("ffrrhdkrrhsxxmfx")
    public fun runScheduledScan(`value`: RunScheduledScan) {
        val toBeMapped = Either.ofRight<String, RunScheduledScan>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.runScheduledScan = mapped
    }

    /**
     * @param value Schedule scan settings day
     */
    @JvmName("jhlnylgcqvbklqot")
    public suspend fun scanDay(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scanDay = mapped
    }

    /**
     * @param value Schedule scan settings time
     */
    @JvmName("phvvrrcxvvtsrkjt")
    public suspend fun scanTimeInMinutes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scanTimeInMinutes = mapped
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("dhsvtanelypoxbon")
    public suspend fun scanType(`value`: Either<String, ScanType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scanType = mapped
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("bdsgcmxyrjreiwnl")
    public fun scanType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ScanType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scanType = mapped
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("pwaaqiftbiyxdult")
    public fun scanType(`value`: ScanType) {
        val toBeMapped = Either.ofRight<String, ScanType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scanType = mapped
    }

    internal fun build(): ConfigurationProfilePreferenceAntiMalwareArgs =
        ConfigurationProfilePreferenceAntiMalwareArgs(
            enableRealTimeProtection = enableRealTimeProtection,
            exclusions = exclusions,
            runScheduledScan = runScheduledScan,
            scanDay = scanDay,
            scanTimeInMinutes = scanTimeInMinutes,
            scanType = scanType,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/automanage/kotlin/inputs/ConfigurationProfilePreferenceAntiMalwareArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automanage.kotlin.inputs

import com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs.builder
import com.pulumi.azurenative.automanage.kotlin.enums.EnableRealTimeProtection
import com.pulumi.azurenative.automanage.kotlin.enums.RunScheduledScan
import com.pulumi.azurenative.automanage.kotlin.enums.ScanType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Automanage configuration profile Antimalware preferences.
 * @property enableRealTimeProtection Enables or disables Real Time Protection
 * @property exclusions Extensions, Paths and Processes that must be excluded from scan
 * @property runScheduledScan Enables or disables a periodic scan for antimalware
 * @property scanDay Schedule scan settings day
 * @property scanTimeInMinutes Schedule scan settings time
 * @property scanType Type of scheduled scan
 */
public data class ConfigurationProfilePreferenceAntiMalwareArgs(
    public val enableRealTimeProtection: Output<Either<String, EnableRealTimeProtection>>? = null,
    public val exclusions: Output<Any>? = null,
    public val runScheduledScan: Output<Either<String, RunScheduledScan>>? = null,
    public val scanDay: Output<String>? = null,
    public val scanTimeInMinutes: Output<String>? = null,
    public val scanType: Output<Either<String, ScanType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs> {
    override fun toJava():
        com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs =
        com.pulumi.azurenative.automanage.inputs.ConfigurationProfilePreferenceAntiMalwareArgs.builder()
            .enableRealTimeProtection(
                enableRealTimeProtection?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .exclusions(exclusions?.applyValue({ args0 -> args0 }))
            .runScheduledScan(
                runScheduledScan?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .scanDay(scanDay?.applyValue({ args0 -> args0 }))
            .scanTimeInMinutes(scanTimeInMinutes?.applyValue({ args0 -> args0 }))
            .scanType(
                scanType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationProfilePreferenceAntiMalwareArgs].
 */
@PulumiTagMarker
public class ConfigurationProfilePreferenceAntiMalwareArgsBuilder internal constructor() {
    private var enableRealTimeProtection: Output<Either<String, EnableRealTimeProtection>>? = null

    private var exclusions: Output<Any>? = null

    private var runScheduledScan: Output<Either<String, RunScheduledScan>>? = null

    private var scanDay: Output<String>? = null

    private var scanTimeInMinutes: Output<String>? = null

    private var scanType: Output<Either<String, ScanType>>? = null

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("gjdwbqardmjccpxh")
    public suspend
    fun enableRealTimeProtection(`value`: Output<Either<String, EnableRealTimeProtection>>) {
        this.enableRealTimeProtection = value
    }

    /**
     * @param value Extensions, Paths and Processes that must be excluded from scan
     */
    @JvmName("dtvvhecuokkxyxqk")
    public suspend fun exclusions(`value`: Output<Any>) {
        this.exclusions = value
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("ddkqmfgdmqxcoees")
    public suspend fun runScheduledScan(`value`: Output<Either<String, RunScheduledScan>>) {
        this.runScheduledScan = value
    }

    /**
     * @param value Schedule scan settings day
     */
    @JvmName("skmbkrwsamqviqgv")
    public suspend fun scanDay(`value`: Output<String>) {
        this.scanDay = value
    }

    /**
     * @param value Schedule scan settings time
     */
    @JvmName("dlerjvihxiqbhtrr")
    public suspend fun scanTimeInMinutes(`value`: Output<String>) {
        this.scanTimeInMinutes = value
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("xdxsumxsbvmrygwq")
    public suspend fun scanType(`value`: Output<Either<String, ScanType>>) {
        this.scanType = value
    }

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("ncgthckjskwiwifw")
    public suspend fun enableRealTimeProtection(`value`: Either<String, EnableRealTimeProtection>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableRealTimeProtection = mapped
    }

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("guwsklmaunftkrkj")
    public fun enableRealTimeProtection(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EnableRealTimeProtection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enableRealTimeProtection = mapped
    }

    /**
     * @param value Enables or disables Real Time Protection
     */
    @JvmName("tuhtetjeonmcfcde")
    public fun enableRealTimeProtection(`value`: EnableRealTimeProtection) {
        val toBeMapped = Either.ofRight<String, EnableRealTimeProtection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enableRealTimeProtection = mapped
    }

    /**
     * @param value Extensions, Paths and Processes that must be excluded from scan
     */
    @JvmName("ydphhmfjaanbumjm")
    public suspend fun exclusions(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("gdfftwnfwbvpfans")
    public suspend fun runScheduledScan(`value`: Either<String, RunScheduledScan>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runScheduledScan = mapped
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("getqvvtlayhhiokv")
    public fun runScheduledScan(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RunScheduledScan>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.runScheduledScan = mapped
    }

    /**
     * @param value Enables or disables a periodic scan for antimalware
     */
    @JvmName("ikrccdcyymfrolda")
    public fun runScheduledScan(`value`: RunScheduledScan) {
        val toBeMapped = Either.ofRight<String, RunScheduledScan>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.runScheduledScan = mapped
    }

    /**
     * @param value Schedule scan settings day
     */
    @JvmName("peoseprqifaecfag")
    public suspend fun scanDay(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scanDay = mapped
    }

    /**
     * @param value Schedule scan settings time
     */
    @JvmName("onmjkqrtixjqtknr")
    public suspend fun scanTimeInMinutes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scanTimeInMinutes = mapped
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("axqadlaumowybrxb")
    public suspend fun scanType(`value`: Either<String, ScanType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scanType = mapped
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("ikqkwmwvwcsjqobm")
    public fun scanType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ScanType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scanType = mapped
    }

    /**
     * @param value Type of scheduled scan
     */
    @JvmName("lhqbkiigyojgattr")
    public fun scanType(`value`: ScanType) {
        val toBeMapped = Either.ofRight<String, ScanType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scanType = mapped
    }

    internal fun build(): ConfigurationProfilePreferenceAntiMalwareArgs =
        ConfigurationProfilePreferenceAntiMalwareArgs(
            enableRealTimeProtection = enableRealTimeProtection,
            exclusions = exclusions,
            runScheduledScan = runScheduledScan,
            scanDay = scanDay,
            scanTimeInMinutes = scanTimeInMinutes,
            scanType = scanType,
        )
}
